==> zio-aws-redshift_3-5.17.152.1-sources.jar: zio/aws/redshift/model/DescribeClusterParametersRequest.scala <==
package zio.aws.redshift.model
import java.lang.Integer
import zio.aws.redshift.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeClusterParametersRequest(
    parameterGroupName: String,
    source: Option[String] = None,
    maxRecords: Option[IntegerOptional] = None,
    marker: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest = {
    import DescribeClusterParametersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest
      .builder()
      .parameterGroupName(parameterGroupName: java.lang.String)
      .optionallyWith(source.map(value => value: java.lang.String))(_.source)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.DescribeClusterParametersRequest.ReadOnly =
    zio.aws.redshift.model.DescribeClusterParametersRequest
      .wrap(buildAwsValue())
}
object DescribeClusterParametersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.DescribeClusterParametersRequest =
      zio.aws.redshift.model.DescribeClusterParametersRequest(
        parameterGroupName,
        source.map(value => value),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def parameterGroupName: String
    def source: Option[String]
    def maxRecords: Option[IntegerOptional]
    def marker: Option[String]
    def getParameterGroupName: ZIO[Any, Nothing, String] =
      ZIO.succeed(parameterGroupName)
    def getSource: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("source", source)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest
  ) extends zio.aws.redshift.model.DescribeClusterParametersRequest.ReadOnly {
    override val parameterGroupName: String = impl.parameterGroupName(): String
    override val source: Option[String] =
      scala.Option(impl.source()).map(value => value: String)
    override val maxRecords: Option[IntegerOptional] =
      scala.Option(impl.maxRecords()).map(value => value: IntegerOptional)
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest
  ): zio.aws.redshift.model.DescribeClusterParametersRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshift_3-5.19.31.3-sources.jar: zio/aws/redshift/model/DescribeClusterParametersRequest.scala <==
package zio.aws.redshift.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.redshift.model.primitives.IntegerOptional
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class DescribeClusterParametersRequest(
    parameterGroupName: String,
    source: Optional[String] = Optional.Absent,
    maxRecords: Optional[IntegerOptional] = Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest = {
    import DescribeClusterParametersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest
      .builder()
      .parameterGroupName(parameterGroupName: java.lang.String)
      .optionallyWith(source.map(value => value: java.lang.String))(_.source)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.DescribeClusterParametersRequest.ReadOnly =
    zio.aws.redshift.model.DescribeClusterParametersRequest
      .wrap(buildAwsValue())
}
object DescribeClusterParametersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.DescribeClusterParametersRequest =
      zio.aws.redshift.model.DescribeClusterParametersRequest(
        parameterGroupName,
        source.map(value => value),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def parameterGroupName: String
    def source: Optional[String]
    def maxRecords: Optional[IntegerOptional]
    def marker: Optional[String]
    def getParameterGroupName: ZIO[Any, Nothing, String] =
      ZIO.succeed(parameterGroupName)
    def getSource: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("source", source)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest
  ) extends zio.aws.redshift.model.DescribeClusterParametersRequest.ReadOnly {
    override val parameterGroupName: String = impl.parameterGroupName(): String
    override val source: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.source())
      .map(value => value: String)
    override val maxRecords: Optional[IntegerOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.maxRecords())
      .map(value => value: IntegerOptional)
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.DescribeClusterParametersRequest
  ): zio.aws.redshift.model.DescribeClusterParametersRequest.ReadOnly =
    new Wrapper(impl)
}
